@@ -148,30 +148,38 @@ async def file_transfer_get(bucket, bucket_name, refresh='no'):
                     print('remote has record->{}, ignored.'.format(task_id))
                     return
 
-        file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
-        if not os.path.isfile(file_path):
-            ret, e = minio.download_file(file_path, bucket, bucket_name)
+        with cache_engine.lock(task_id) as lock:
+            remote_state = await cache_engine.get_cache_async(task_id)
+            if remote_state is not None:
+                ret = remote_state['ret']
+                if ret:
+                    print('remote has record->{}, ignored.'.format(task_id))
+                    return
+
+            file_path = os.path.join(cache_path, '{}_{}'.format(bucket, bucket_name))
+            if not os.path.isfile(file_path):
+                ret, e = minio.download_file(file_path, bucket, bucket_name)
+                if ret:
+                    file_path = e
+                else:
+                    cache_engine.cache(task_id, {
+                        'ret': False, 
+                        'err': e.message
+                    }, expired=60)
+                    return
+
+            ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
             if ret:
-                file_path = e
+                cache_engine.cache(task_id, {
+                    'ret': True,
+                    'url': e
+                }, expired=60 * 60 * 24 * 1)
+                print('upload success!!')
             else:
                 cache_engine.cache(task_id, {
                     'ret': False, 
-                    'err': e.message
+                    'err': e
                 }, expired=60)
-                return
-
-        ret, e = hmfs_client.put_to_cloud(file_path, bucket, bucket_name)
-        if ret:
-            cache_engine.cache(task_id, {
-                'ret': True,
-                'url': e
-            }, expired=60 * 60 * 24 * 1)
-            print('upload success!!')
-        else:
-            cache_engine.cache(task_id, {
-                'ret': False, 
-                'err': e
-            }, expired=60)
     except Exception as e:
         traceback.print_exc()
     
